@@ -201,23 +201,30 @@ sub login {
     my $login = shift;
     my $password = shift;
     my $cfg = $self->app->config->cfgHash;
+    my $remoteAddress = eval { $self->controller->tx->remote_address } // 'UNKNOWN_IP';
     if ($cfg->{sesame_pass} and $cfg->{sesame_user}
         and $login and $password
         and $login eq $cfg->{sesame_user}
         and hmac_sha1_sum($password) eq $cfg->{sesame_pass}){
+        $self->log->info("SESAME Login for $login from $remoteAddress successful");
         $self->session(userId=>'__ROOT');
         return 1;
     }
 
     my $db = $self->app->database;
     my $userData = $db->fetchRow('cbuser',{login=>$login});
-    return undef if not $userData;
+    if (not $userData) {
+        $self->log->info("Login attempt with unknown user $login from $remoteAddress failed");
+        return undef;
+    }
 
     if ($userData->{cbuser_password} and $password
         and hmac_sha1_sum($password) eq $userData->{cbuser_password} ){
         $self->userId($userData->{cbuser_id});
+        $self->log->info("Login for $login from $remoteAddress successful");
         return 1;
     }
+    $self->log->info("Login attempt with wrong password for $login from $remoteAddress failed");
     return undef;
 }
 
